Aggregator.App.index\_query.IndexAggregator.\_\_init\_\_
========================================================

.. currentmodule:: Aggregator.App.index_query

.. automethod:: IndexAggregator.__init__